==> pymanopt-1.0.0.tar.gz: pymanopt-1.0.0/README.md <==
<a href="https://pymanopt.org"><img src="docs/logo.png?raw=true" width="150" align="right"/></a>

# Pymanopt

> A Python toolbox for optimization on Riemannian manifolds with support for
> automatic differentiation.

| Overview |   |
| -------- | - |
| Latest version | [![Latest version](https://badge.fury.io/py/pymanopt.svg)](https://badge.fury.io/py/pymanopt) |
| Downloads | [![Downloads](https://static.pepy.tech/personalized-badge/pymanopt?period=total&units=international_system&left_color=grey&right_color=green&left_text=Downloads)](https://pepy.tech/project/pymanopt) |
| Build status | [![Build status](https://github.com/pymanopt/pymanopt/actions/workflows/run_tests.yml/badge.svg)](https://github.com/pymanopt/pymanopt/actions/workflows/run_tests.yml) |
| Coverage | [![Coverage](https://coveralls.io/repos/github/pymanopt/pymanopt/badge.svg?branch=master)](https://coveralls.io/github/pymanopt/pymanopt?branch=master) |
| Code quality | [![Codacy Badge](https://app.codacy.com/project/badge/Grade/6de2ef56791d4c3b8eb991f66e250a28)](https://www.codacy.com/gh/pymanopt/pymanopt/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=pymanopt/pymanopt&amp;utm_campaign=Badge_Grade) [![Total alerts](https://img.shields.io/lgtm/alerts/g/pymanopt/pymanopt.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/pymanopt/pymanopt/alerts/) [![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/pymanopt/pymanopt.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/pymanopt/pymanopt/context:python) |
| Community | [![Gitter](https://badges.gitter.im/pymanopt/pymanopt.svg)](https://gitter.im/pymanopt/pymanopt?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge) |

Please refer to the **[documentation](https://pymanopt.org/docs/)** and this
[JMLR paper](http://www.jmlr.org/papers/v17/16-177.html) to get started with
optimization on manifolds using Pymanopt.
If you wish to extend Pymanopt's functionality and/or contribute to the project
please refer to the [contributing guide](CONTRIBUTING.md).

We encourage users and developers to report problems, request features,
ask for help, or leave general comments either here on github or on
[gitter](https://gitter.im/pymanopt/pymanopt).

Pymanopt is distributed under the [3-clause BSD license](LICENSE).

==> pymanopt-2.0.1.tar.gz: pymanopt-2.0.1/README.md <==
<a href="https://pymanopt.org"><img src="docs/logo.png?raw=true" width="150" align="right"/></a>

# Pymanopt

> A Python toolbox for optimization on Riemannian manifolds with support for
> automatic differentiation.

| Overview |   |
| -------- | - |
| Latest version | [![Latest version](https://badge.fury.io/py/pymanopt.svg)](https://badge.fury.io/py/pymanopt) [![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.6549953.svg)](https://doi.org/10.5281/zenodo.6549953) |
| Downloads | [![Downloads](https://static.pepy.tech/personalized-badge/pymanopt?period=total&units=international_system&left_color=grey&right_color=green&left_text=Downloads)](https://pepy.tech/project/pymanopt) |
| Build status | [![Build status](https://github.com/pymanopt/pymanopt/actions/workflows/run_tests.yml/badge.svg)](https://github.com/pymanopt/pymanopt/actions/workflows/run_tests.yml) |
| Coverage | [![Coverage](https://coveralls.io/repos/github/pymanopt/pymanopt/badge.svg?branch=master)](https://coveralls.io/github/pymanopt/pymanopt?branch=master) |
| Code quality | [![Codacy Badge](https://app.codacy.com/project/badge/Grade/6de2ef56791d4c3b8eb991f66e250a28)](https://www.codacy.com/gh/pymanopt/pymanopt/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=pymanopt/pymanopt&amp;utm_campaign=Badge_Grade) [![Total alerts](https://img.shields.io/lgtm/alerts/g/pymanopt/pymanopt.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/pymanopt/pymanopt/alerts/) [![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/pymanopt/pymanopt.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/pymanopt/pymanopt/context:python) |
| Community | [![Gitter](https://badges.gitter.im/pymanopt/pymanopt.svg)](https://gitter.im/pymanopt/pymanopt?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge) |

Please refer to the **[documentation](https://pymanopt.org/docs/)** and this
[JMLR paper](http://www.jmlr.org/papers/v17/16-177.html) to get started with
optimization on manifolds using Pymanopt.
If you wish to extend Pymanopt's functionality and/or contribute to the project
please refer to the [contributing guide](CONTRIBUTING.md).

We encourage users and developers to report problems, request features,
ask for help, or leave general comments either here on github or on
[gitter](https://gitter.im/pymanopt/pymanopt).

Pymanopt is distributed under the [3-clause BSD license](LICENSE).
